LINK_HTML = (
    '<a id="id_of_link" class="link-class" name="name_of_link" href="http://i_am_a_link.com/" rel="noreferrer">'
    "the text obviously"
    "</a>"
)
